@@ -145,8 +145,7 @@ class FollowupMissed:
     coire_file = self.cache.sieve(description = "FOUND").checkfilesexist()[0].pfnlist()[0]
     try:
       doc = SearchSummaryUtils.ReadTablesFromFiles([coire_file],[ lsctables.ProcessParamsTable])
-      process_params = table.get_table(doc, lsctables.ProcessParamsTable.\
-                                       tableName)
+      process_params = lsctables.ProcessParamsTable.get_table(doc)
     except IOError: 	    
       sys.stderr.write("ERROR (IOError) while reading process_params table from file %s. "\
                        "Does this file exist and does it contain a search_summary table?\n" %(coire_file))
