@@ -270,13 +270,7 @@ def get_mean_mchirp(coinc):
 
 def load_external_triggers(filename):
     doc = ligolw_add.ligolw_add(ligolw.Document(), [filename])
-    ext_trigger_tables = lsctables.table.getTablesByName(doc, lsctables.ExtTriggersTable.tableName)
-    if ext_trigger_tables is None:
-        print >>sys.stderr, "No tables named external_trigger:table found in " + filename
-    else:
-        assert len(ext_trigger_tables) == 1  # ligolw_add should merge them
-        ext_triggers = ext_trigger_tables[0]
-    return ext_triggers
+    return lsctables.ExtTriggersTable.get_table(doc)
 
 def write_rows(rows, table_type, filename):
     """
@@ -333,13 +327,10 @@ def get_num_slides(xmldoc):
     Return the value of --num-slides found in the process_params table of
     xmldoc.  If no such entry is found, return 0.
     """
-    tbl_name = lsctables.ProcessParamsTable.tableName
-
     # don't be too picky what program had --num-slides
-    for tbl in table.getTablesByName(xmldoc, tbl_name):
-        for row in tbl:
-           if row.param == "--num-slides":
-               return int(row.value)
+    for row in lsctables.ProcessParamsTable.get_table(xmldoc):
+       if row.param == "--num-slides":
+           return int(row.value)
     return 0
 #####################################################################################
 #timeslides functions#
