@@ -46,14 +46,9 @@ from glue.ligolw.utils import process as ligolw_process
 from pylal import git_version
 from pylal import ligolw_thinca
 from pylal import ligolw_rinca
-from pylal import ligolw_tisi
+from lalburst import timeslides as ligolw_tisi
 from pylal import SimInspiralUtils
 from pylal import SnglInspiralUtils
-from pylal.xlal import tools
-from pylal.xlal.datatypes.ligotimegps import LIGOTimeGPS
-
-
-lsctables.CoincMapTable.RowType = lsctables.CoincMap = tools.CoincMap
 
 
 __author__ = "Kipp Cannon <kipp.cannon@ligo.org>"
@@ -70,9 +65,6 @@ __date__ = git_version.date
 #
 
 
-lsctables.LIGOTimeGPS = LIGOTimeGPS
-
-
 def sngl_inspiral___cmp__(self, other):
 	# compare self's end time to the LIGOTimeGPS instance other
 	return cmp(self.end_time, other.seconds) or cmp(self.end_time_ns, other.nanoseconds)
@@ -315,16 +307,16 @@ def InspiralSnglCompare(sim, inspiral):
         """
 	Return False if the peak time of the sim is within 9 seconds of the inspiral event.
         """
-	return SnglInspiralUtils.CompareSnglInspiral(sim, inspiral, twindow = LIGOTimeGPS(9))
+	return SnglInspiralUtils.CompareSnglInspiral(sim, inspiral, twindow = lsctables.LIGOTimeGPS(9))
 
 
 def InspiralNearCoincCompare(sim, inspiral):
 	"""
 	Return False if the peak time of the sim is within 9 seconds of the inspiral event.
 	"""
-	return SnglInspiralUtils.CompareSnglInspiral(sim, inspiral, twindow = LIGOTimeGPS(9))
+	return SnglInspiralUtils.CompareSnglInspiral(sim, inspiral, twindow = lsctables.LIGOTimeGPS(9))
 
-def cmp_sngl_sim(sim, sngl, get_sim_time, get_sngl_time, twindow = LIGOTimeGPS(9)):
+def cmp_sngl_sim(sim, sngl, get_sim_time, get_sngl_time, twindow = lsctables.LIGOTimeGPS(9)):
 	tdiff = abs(get_sngl_time(sngl) - get_sim_time(sim))
 	if tdiff < twindow:
 	  return 0
