@@ -1,4 +1,4 @@
-# Copyright (C) 2006--2014  Kipp Cannon, Drew G. Keppel, Jolien Creighton
+# Copyright (C) 2006--2016  Kipp Cannon, Drew G. Keppel, Jolien Creighton
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -49,17 +49,18 @@ import sys
 import warnings
 
 
+import lal
+
+
 from glue import iterutils
 from glue import offsetvector
 from glue import segmentsUtils
 from glue.ligolw import ligolw
 from glue.ligolw import array as ligolw_array
 from glue.ligolw import param as ligolw_param
-from glue.ligolw import table as ligolw_table
 from glue.ligolw import lsctables
 from glue.text_progress_bar import ProgressBar
 from pylal import git_version
-from pylal import inject
 from pylal import rate
 
 
@@ -162,7 +163,7 @@ class EventListDict(dict):
 		# wrapper to shield dict.__new__() from our arguments.
 		return dict.__new__(cls)
 
-	def __init__(self, EventListType, event_table, process_ids = None):
+	def __init__(self, EventListType, event_table, instruments = None, process_ids = None):
 		"""
 		Initialize a newly-created instance.  EventListType is a
 		subclass of EventList (the subclass itself, not an instance
@@ -174,14 +175,15 @@ class EventListDict(dict):
 		process_ids whose events should be considered in the
 		coincidence analysis, otherwise all events are considered.
 		"""
-		for event in event_table:
-			if (process_ids is None) or (event.process_id in process_ids):
-				# FIXME:  only works when the instrument
-				# name is in the "ifo" column.  true for
-				# inspirals, bursts and ringdowns
-				if event.ifo not in self:
-					self[event.ifo] = EventListType(event.ifo)
+		for instrument in instruments if instruments is not None else set(event_table.getColumnByName("ifo")):
+			self[instrument] = EventListType(instrument)
+		if process_ids is None:
+			for event in event_table:
 				self[event.ifo].append(event)
+		else:
+			for event in event_table:
+				if event.process_id in process_ids:
+					self[event.ifo].append(event)
 		for l in self.values():
 			l.make_index()
 
@@ -209,16 +211,6 @@ class EventListDict(dict):
 			eventlist.set_offset(0)
 
 
-def make_eventlists(xmldoc, EventListType, event_table_name, process_ids = None):
-	"""
-	Convenience wrapper for constructing a dictionary of event lists
-	from an XML document tree, the name of a table from which to get
-	the events, a maximum allowed time window, and the name of the
-	program that generated the events.
-	"""
-	return EventListDict(EventListType, ligolw_table.get_table(xmldoc, event_table_name), process_ids = process_ids)
-
-
 #
 # =============================================================================
 #
@@ -228,6 +220,19 @@ def make_eventlists(xmldoc, EventListType, event_table_name, process_ids = None)
 #
 
 
+def light_travel_time(instrument1, instrument2):
+	"""
+	Compute and return the time required for light to travel through
+	free space the distance separating the two instruments.  The inputs
+	are two instrument prefixes (e.g., "H1"), and the result is
+	returned in seconds.  Note how this differs from LAL's
+	XLALLightTravelTime() function, which takes two detector objects as
+	input, and returns the time truncated to integer nanoseconds.
+	"""
+	dx = lal.cached_detector_by_prefix[instrument1].location - lal.cached_detector_by_prefix[instrument2].location
+	return math.sqrt((dx * dx).sum()) / lal.C_SI
+
+
 def get_doubles(eventlists, comparefunc, instruments, thresholds, verbose = False):
 	"""
 	Given an instance of an EventListDict, an event comparison
@@ -296,7 +301,7 @@ def get_doubles(eventlists, comparefunc, instruments, thresholds, verbose = Fals
 		threshold_data = thresholds[(eventlista.instrument, eventlistb.instrument)]
 	except KeyError as e:
 		raise KeyError("no coincidence thresholds provided for instrument pair %s, %s" % e.args[0])
-	light_travel_time = inject.light_travel_time(eventlista.instrument, eventlistb.instrument)
+	dt = light_travel_time(eventlista.instrument, eventlistb.instrument)
 
 	# for each event in the shortest list
 
@@ -307,7 +312,7 @@ def get_doubles(eventlists, comparefunc, instruments, thresholds, verbose = Fals
 		# iterate over events from the other list that are
 		# coincident with the event, and return the pairs
 
-		for eventb in eventlistb.get_coincs(eventa, eventlista.offset, light_travel_time, threshold_data, comparefunc):
+		for eventb in eventlistb.get_coincs(eventa, eventlista.offset, dt, threshold_data, comparefunc):
 			yield (eventa, eventb)
 	if verbose:
 		print >>sys.stderr, "\t100.0%"
@@ -333,6 +338,7 @@ class TimeSlideGraphNode(object):
 		self.coincs = None
 		self.unused_coincs = set()
 
+	@property
 	def name(self):
 		return self.offset_vector.__str__(compact = True)
 
@@ -354,18 +360,13 @@ class TimeSlideGraphNode(object):
 		if self.components is None:
 			if verbose:
 				print >>sys.stderr, "\tconstructing %s ..." % str(self.offset_vector)
+
 			#
-			# can we do it?
+			# sanity check input
 			#
 
-			assert len(self.offset_vector) == 2
-			avail_instruments = set(eventlists)
-			offset_instruments = set(self.offset_vector)
-			if not offset_instruments.issubset(avail_instruments):
-				if verbose:
-					print >>sys.stderr, "\twarning: do not have data for instrument(s) %s ... assuming 0 coincs" % ", ".join(offset_instruments - avail_instruments)
-				self.coincs = tuple()
-				return self.coincs
+			assert len(self.offset_vector) == 2, "broken graph:  node with no components has %d-component offset vector, must be 2" % len(self.offset_vector)
+			assert set(self.offset_vector) <= set(eventlists), "no event list for instrument(s) %s" % ", ".join(sorted(set(self.offset_vector) - set(eventlists)))
 
 			#
 			# apply offsets to events
@@ -390,7 +391,9 @@ class TimeSlideGraphNode(object):
 			# tuple returned by get_doubles() is arbitrary so
 			# we need to sort each tuple by instrument name
 			# explicitly
-			self.coincs = tuple(sorted((a.event_id, b.event_id) if a.ifo <= b.ifo else (b.event_id, a.event_id) for (a, b) in get_doubles(eventlists, event_comparefunc, offset_instruments, thresholds, verbose = verbose)))
+			self.unused_coincs = set((event.event_id,) for instrument in self.offset_vector for event in eventlists[instrument])
+			self.coincs = tuple(sorted((a.event_id, b.event_id) if a.ifo <= b.ifo else (b.event_id, a.event_id) for (a, b) in get_doubles(eventlists, event_comparefunc, tuple(self.offset_vector), thresholds, verbose = verbose)))
+			self.unused_coincs -= set((event_id,) for coinc in self.coincs for event_id in coinc)
 			return self.coincs
 
 		#
@@ -525,11 +528,12 @@ class TimeSlideGraphNode(object):
 class TimeSlideGraph(object):
 	def __init__(self, offset_vector_dict, verbose = False):
 		#
-		# validate input
+		# safety check input
 		#
 
-		if min(len(offset_vector) for offset_vector in offset_vector_dict.values()) < 2:
-			raise ValueError("offset vectors must have at least two instruments")
+		offset_vector = min(offset_vector_dict.values(), key = lambda x: len(x))
+		if len(offset_vector) < 2:
+			raise ValueError("encountered offset vector with fewer than 2 instruments: %s", str(offset_vector))
 
 		#
 		# populate the graph head nodes.  these represent the
@@ -607,25 +611,20 @@ class TimeSlideGraph(object):
 		if verbose:
 			print >>sys.stderr, "graph contains:"
 			for n in sorted(self.generations):
-				print >>sys.stderr,"\t%d %d-insrument offset vectors (%s)" % (len(self.generations[n]), n, ((n == 2) and "to be constructed directly" or "to be constructed indirectly"))
+				print >>sys.stderr,"\t%d %d-insrument offset vectors (%s)" % (len(self.generations[n]), n, ("to be constructed directly" if n == 2 else "to be constructed indirectly"))
 			print >>sys.stderr, "\t%d offset vectors total" % sum(len(self.generations[n]) for n in self.generations)
 
 
-	def get_coincs(self, eventlists, event_comparefunc, thresholds, include_small_coincs = True, verbose = False):
+	def get_coincs(self, eventlists, event_comparefunc, thresholds, verbose = False):
 		if verbose:
 			print >>sys.stderr, "constructing coincs for target offset vectors ..."
 		for n, node in enumerate(self.head, start = 1):
 			if verbose:
 				print >>sys.stderr, "%d/%d: %s" % (n, len(self.head), str(node.offset_vector))
-			if include_small_coincs:
-				# note that unused_coincs must be retrieved
-				# after the call to .get_coincs() because
-				# the former is computed as a side effect
-				# of the latter
-				iterator = itertools.chain(node.get_coincs(eventlists, event_comparefunc, thresholds, verbose), node.unused_coincs)
-			else:
-				iterator = node.get_coincs(eventlists, event_comparefunc, thresholds, verbose)
-			for coinc in iterator:
+			# note that unused_coincs must be retrieved after
+			# the call to .get_coincs() because the former is
+			# computed as a side effect of the latter
+			for coinc in itertools.chain(node.get_coincs(eventlists, event_comparefunc, thresholds, verbose), node.unused_coincs):
 				yield node, coinc
 
 
@@ -636,14 +635,14 @@ class TimeSlideGraph(object):
 		"""
 		print >>fileobj, "digraph \"Time Slides\" {"
 		for node in itertools.chain(*self.generations.values()):
-			print >>fileobj, "\t\"%s\" [shape=box];" % node.name()
+			print >>fileobj, "\t\"%s\" [shape=box];" % node.name
 			if node.components is not None:
 				for component in node.components:
-					print >>fileobj, "\t\"%s\" -> \"%s\";" % (component.name(), node.name())
+					print >>fileobj, "\t\"%s\" -> \"%s\";" % (component.name, node.name)
 		for node in self.head:
-			print >>fileobj, "\t\"%s\" [shape=ellipse];" % node.name()
+			print >>fileobj, "\t\"%s\" [shape=ellipse];" % node.name
 			for component in node.components:
-				print >>fileobj, "\t\"%s\" -> \"%s\";" % (component.name(), node.name())
+				print >>fileobj, "\t\"%s\" -> \"%s\";" % (component.name, node.name)
 		print >>fileobj, "}"
 
 
@@ -687,40 +686,64 @@ class CoincTables(object):
 		# required.  when that is fixed, remove this
 		self.time_slide_index = dict((time_slide_id, type(offset_vector)((instrument, lsctables.LIGOTimeGPS(offset)) for instrument, offset in offset_vector.items())) for time_slide_id, offset_vector in self.time_slide_index.items())
 
-	def append_coinc(self, process_id, time_slide_id, coinc_def_id, events):
+	def coinc_rows(self, process_id, time_slide_id, coinc_def_id, events):
 		"""
-		Takes a process ID, a time slide ID, and a list of events,
-		and adds the events as a new coincidence to the coinc_event
-		and coinc_map tables.
+		From a process ID, a time slide ID, and a sequence of
+		events (generator expressions are OK), constructs and
+		initializes a coinc_event table row object and a sequence
+		of coinc_event_map table row objects describing the
+		coincident event.  The return value is the coinc_event row
+		and a sequence of the coinc_event_map rows.
 
-		Subclasses that wish to override this method should first
-		chain to this method to construct and initialize the
-		coinc_event and coinc_event_map rows.  When subclassing
-		this method, if the time shifts that were applied to the
-		events in constructing the coincidence are required to
-		compute additional metadata, they can be retrieved from
-		self.time_slide_index using the time_slide_id.
+		The coinc_event is *not* assigned a coinc_event_id by this
+		method.  It is expected that will be done in
+		.append_coinc().  This allows sub-classes to defer the
+		question of whether or not to include the coincidence in
+		the search results without consuming additional IDs.
+
+		The coinc_event row's .instruments and .likelihood
+		attributes are initialized to null values.  The calling
+		code should populate as needed.
+
+		When subclassing this method, if the time shifts that were
+		applied to the events in constructing the coincidence are
+		required to compute additional metadata, they can be
+		retrieved from self.time_slide_index using the
+		time_slide_id.
 		"""
-		# so we can iterate over it more than once incase we've
-		# been given a generator expression.
-		events = tuple(events)
-
 		coinc = self.coinctable.RowType()
 		coinc.process_id = process_id
 		coinc.coinc_def_id = coinc_def_id
-		coinc.coinc_event_id = self.coinctable.get_next_id()
+		coinc.coinc_event_id = None
 		coinc.time_slide_id = time_slide_id
 		coinc.set_instruments(None)
-		coinc.nevents = len(events)
 		coinc.likelihood = None
-		self.coinctable.append(coinc)
+
+		coincmaps = []
 		for event in events:
 			coincmap = self.coincmaptable.RowType()
 			coincmap.coinc_event_id = coinc.coinc_event_id
 			coincmap.table_name = event.event_id.table_name
 			coincmap.event_id = event.event_id
-			self.coincmaptable.append(coincmap)
-		return coinc
+			coincmaps.append(coincmap)
+
+		coinc.nevents = len(coincmaps)
+
+		return coinc, coincmaps
+
+	def append_coinc(self, coinc_event_row, coinc_event_map_rows):
+		"""
+		Appends the coinc_event row object and coinc_event_map row
+		objects to the coinc_event and coinc_event_map tables
+		respectively after assigning a coinc_event_id to the
+		coincidence.  Returns the coinc_event row object.
+		"""
+		coinc_event_row.coinc_event_id = self.coinctable.get_next_id()
+		self.coinctable.append(coinc_event_row)
+		for row in coinc_event_map_rows:
+			row.coinc_event_id = coinc_event_row.coinc_event_id
+			self.coincmaptable.append(row)
+		return coinc_event_row
 
 
 #
@@ -740,7 +763,7 @@ class CoincSynthesizer(object):
 	rates related to the problem of doing so.
 	"""
 
-	def __init__(self, eventlists = None, segmentlists = None, delta_t = None, abundance_rel_accuracy = 1e-4):
+	def __init__(self, eventlists = None, segmentlists = None, delta_t = None, min_instruments = 2, abundance_rel_accuracy = 1e-4):
 		"""
 		eventlists is either a dictionary mapping instrument name
 		to a list of the events (arbitrary objects) seen in that
@@ -754,6 +777,8 @@ class CoincSynthesizer(object):
 		window in seconds, the light travel time between instrument
 		pairs is added to this internally to set the maximum
 		allowed coincidence window between a pair of instruments.
+		min_instruments sets the minimum number of instruments that
+		must participate in a coincidence (default is 2).
 
 		abundance_rel_accuracy sets the fractional error tolerated
 		in the Monte Carlo integrator used to estimate the relative
@@ -773,12 +798,20 @@ class CoincSynthesizer(object):
 		{frozenset(['V1', 'H1']): 0.0006034769052553435, frozenset(['V1', 'H1', 'L1']): 1.1793108172576082e-06, frozenset(['H1', 'L1']): 0.000293675897392638, frozenset(['V1', 'L1']): 0.00043917345626762395}
 		>>> coinc_synth.P_live
 		{frozenset(['V1', 'H1']): 0.0, frozenset(['V1', 'H1', 'L1']): 0.25, frozenset(['H1', 'L1']): 0.25, frozenset(['V1', 'L1']): 0.5}
+		>>>
+		>>>
+		>>> coinc_synth = CoincSynthesizer(eventlists, seglists, 0.001, min_instruments = 1)
+		>>> coinc_synth.rates
+		{frozenset(['V1']): 0.08, frozenset(['H1']): 0.13333333333333333, frozenset(['V1', 'H1']): 0.0006034769052553435, frozenset(['L1']): 0.1, frozenset(['V1', 'L1']): 0.00043917345626762395, frozenset(['V1', 'H1', 'L1']): 1.179508868912594e-06, frozenset(['H1', 'L1']): 0.000293675897392638}
 		"""
 		self.eventlists = eventlists if eventlists is not None else dict.fromkeys(segmentlists, 0) if segmentlists is not None else {}
 		self.segmentlists = segmentlists if segmentlists is not None else segmentsUtils.segments.segmentlistdict()
+		if set(self.eventlists) > set(self.segmentlists):
+			raise ValueError("require a segmentlist for each event list")
 		self.delta_t = delta_t
-		# require a segment list for each list of events
-		assert set(self.eventlists) <= set(self.segmentlists)
+		if min_instruments < 1:
+			raise ValueError("min_instruments must be >= 1")
+		self.min_instruments = min_instruments
 		self.abundance_rel_accuracy = abundance_rel_accuracy
 
 		self.verbose = False	# turn on for diagnostics
@@ -791,10 +824,10 @@ class CoincSynthesizer(object):
 		attributes (or their contents) are modified.  This class
 		relies heavily on pre-computed quantities that are derived
 		from the input parameters and cached;  invoking this method
-		forces the recalculation of all cached data (the next time
-		it's needed).  Until this method is invoked, derived data
-		like coincidence window sizes and mean event rates might
-		reflect the previous state of this class.
+		forces the recalculation of cached data (the next time it's
+		needed).  Until this method is invoked, derived data like
+		coincidence window sizes and mean event rates might reflect
+		the previous state of this class.
 		"""
 		try:
 			del self._P_live
@@ -821,24 +854,24 @@ class CoincSynthesizer(object):
 		frozensets).
 		"""
 		all_instruments = tuple(self.eventlists)
-		return tuple(frozenset(instruments) for n in range(2, len(all_instruments) + 1) for instruments in iterutils.choices(all_instruments, n))
+		return tuple(frozenset(instruments) for n in range(self.min_instruments, len(all_instruments) + 1) for instruments in iterutils.choices(all_instruments, n))
 
 
 	@property
 	def P_live(self):
 		"""
 		Dictionary mapping instrument combination (as a frozenset)
-		to fraction of the total time for which at least two
-		instruments were on during which precisely that combination
-		of instruments (and no other instruments) are on.  E.g.,
-		P_live[frozenset(("H1", "L1"))] gives the probability that
-		precisely H1 and L1 are the only instruments operating
-		given that at least two instruments are operating.
+		to fraction of the total time in which the minimum required
+		number of instruments were on during which precisely that
+		combination of instruments (and no other instruments) are
+		on.  E.g., P_live[frozenset(("H1", "L1"))] gives the
+		probability that precisely H1 and L1 are the only
+		instruments operating.
 		"""
 		try:
 			return self._P_live
 		except AttributeError:
-			livetime = float(abs(segmentsUtils.vote(self.segmentlists.values(), 2)))
+			livetime = float(abs(segmentsUtils.vote(self.segmentlists.values(), self.min_instruments)))
 			all_instruments = set(self.segmentlists)
 			self._P_live = dict((instruments, float(abs(self.segmentlists.intersection(instruments) - self.segmentlists.union(all_instruments - instruments))) / livetime) for instruments in self.all_instrument_combos)
 			# check normalization
@@ -897,7 +930,7 @@ class CoincSynthesizer(object):
 		try:
 			return self._tau
 		except AttributeError:
-			self._tau = dict((frozenset(ab), self.delta_t + inject.light_travel_time(*ab)) for ab in iterutils.choices(tuple(self.eventlists), 2))
+			self._tau = dict((frozenset(ab), self.delta_t + light_travel_time(*ab)) for ab in iterutils.choices(tuple(self.eventlists), 2))
 			return self._tau
 
 
@@ -993,19 +1026,20 @@ class CoincSynthesizer(object):
 		# variance = d p (1 - p) <= d/4 where p is the probability
 		# of a successful outcome.  we quit when the ratio of the
 		# bound on the standard deviation of the number of
-		# successful outcomes to the actual number of successful
-		# outcomes falls below rel accuracy: \sqrt{d/4} / n < rel
-		# accuracy.  note that if the true probability is 0, so
-		# that n=0 identically, then the loop will never terminate;
-		# from the nature of the problem we know 0<p<1 so the loop
-		# will, eventually, terminate.  note that if instead of
-		# using the upper bound on the variance, we replace p with
-		# (n/d) and use that estimate of the variance the loop can
-		# be shown to require many fewer iterations to meet the
-		# desired accuracy, but that choice creates a rather strong
-		# bias that, to overcome, requires some extra hacks to
-		# force the loop to run for additional iterations.  this
-		# approach is cleaner.
+		# successful outcomes (d/4) to the actual number of
+		# successful outcomes (n) falls below rel accuracy:
+		# \sqrt{d/4} / n < rel accuracy.  note that if the true
+		# probability is 0, so that n=0 identically, then the loop
+		# will never terminate; from the nature of the problem we
+		# know 0<p<1 so the loop will, eventually, terminate.  note
+		# that if instead of using the upper bound on the variance,
+		# we replace p with the estimate of p at the current
+		# iteration (=n/d) and use that to estimate the variance
+		# the loop can be shown to require many fewer iterations to
+		# meet the desired accuracy, but that choice creates a
+		# rather strong bias that, to overcome, requires some extra
+		# hacks to force the loop to run for additional iterations.
+		# the approach used here is much simpler.
 					math_sqrt = math.sqrt
 					random_uniform = random.uniform
 					epsilon = self.abundance_rel_accuracy
@@ -1049,9 +1083,10 @@ class CoincSynthesizer(object):
 		Dictionary mapping instrument combo (as a frozenset) to the
 		mean rate at which coincidences involving precisely that
 		combination of instruments occur, averaged over times when
-		at least two instruments are operating --- the mean rate
-		during times when coincidences are possible, not the mean
-		rate over all time.  The result is not cached.
+		at least the minimum required number of instruments are
+		operating --- the mean rate during times when coincidences
+		are possible, not the mean rate over all time.  The result
+		is not cached.
 		"""
 		coinc_rate = dict.fromkeys(self.rates, 0.0)
 		# iterate over probabilities in order for better numerical
@@ -1110,7 +1145,7 @@ class CoincSynthesizer(object):
 		precisely that combination of instruments expected from the
 		background.  The result is not cached.
 		"""
-		T = float(abs(segmentsUtils.vote(self.segmentlists.values(), 2)))
+		T = float(abs(segmentsUtils.vote(self.segmentlists.values(), self.min_instruments)))
 		return dict((instruments, rate * T) for instruments, rate in self.mean_coinc_rate.items())
 
 
@@ -1183,10 +1218,11 @@ class CoincSynthesizer(object):
 		contained in self.eventlists.
 
 		If allow_zero_lag is False (the default), then only event tuples
-		with no genuine zero-lag coincidences are returned, that is only
-		tuples in which no event pairs would be considered to be coincident
-		without time shifts applied.
-
+		with no genuine zero-lag coincidences are returned, that is
+		only tuples in which no event pairs would be considered to
+		be coincident without time shifts applied.  Note that
+		single-instrument "coincidences", if allowed, are *not*
+		considered to be zero-lag coincidences.
 
 		Example:
 
@@ -1793,20 +1829,21 @@ class CoincParamsDistributions(object):
 		__getitem__ = self.injection_lnpdf_interp.__getitem__
 		return sum(__getitem__(name)(*value) for name, value in params.items())
 
-	def get_xml_root(self, xml, name):
+	@classmethod
+	def get_xml_root(cls, xml, name):
 		"""
 		Sub-classes can use this in their overrides of the
 		.from_xml() method to find the root element of the XML
 		serialization.
 		"""
-		name = u"%s:%s" % (name, self.ligo_lw_name_suffix)
+		name = u"%s:%s" % (name, cls.ligo_lw_name_suffix)
 		xml = [elem for elem in xml.getElementsByTagName(ligolw.LIGO_LW.tagName) if elem.hasAttribute(u"Name") and elem.Name == name]
 		if len(xml) != 1:
 			raise ValueError("XML tree must contain exactly one %s element named %s" % (ligolw.LIGO_LW.tagName, name))
 		return xml[0]
 
 	@classmethod
-	def from_xml(cls, xml, name):
+	def from_xml(cls, xml, name, **kwargs):
 		"""
 		In the XML document tree rooted at xml, search for the
 		serialized CoincParamsDistributions object named name, and
@@ -1815,14 +1852,14 @@ class CoincParamsDistributions(object):
 		CoincParamsDistributions object, the second is the process
 		ID recorded when it was written to XML.
 		"""
-		# create an instance
-		self = cls()
-
 		# find the root element of the XML serialization
-		xml = self.get_xml_root(xml, name)
+		xml = cls.get_xml_root(xml, name)
 
 		# retrieve the process ID
-		self.process_id = ligolw_param.get_pyvalue(xml, u"process_id")
+		process_id = ligolw_param.get_pyvalue(xml, u"process_id")
+
+		# create an instance
+		self = cls(process_id = process_id, **kwargs)
 
 		# reconstruct the BinnedArray objects
 		def reconstruct(xml, prefix, target_dict):
@@ -1856,7 +1893,7 @@ class CoincParamsDistributions(object):
 		given the name name.
 		"""
 		xml = ligolw.LIGO_LW({u"Name": u"%s:%s" % (name, self.ligo_lw_name_suffix)})
-		xml.appendChild(ligolw_param.new_param(u"process_id", u"ilwd:char", self.process_id))
+		xml.appendChild(ligolw_param.Param.from_pyvalue(u"process_id", self.process_id))
 		def store(xml, prefix, source_dict):
 			for name, binnedarray in sorted(source_dict.items()):
 				xml.appendChild(binnedarray.to_xml(u"%s:%s" % (prefix, name)))
